summaryrefslogtreecommitdiff
path: root/include/llvm
diff options
context:
space:
mode:
authorDuraid Madina <duraid@octopus.com.au>2005-04-11 07:14:41 +0000
committerDuraid Madina <duraid@octopus.com.au>2005-04-11 07:14:41 +0000
commit2d4c88311801d6eba48b257a43aee8a6d61299a6 (patch)
tree3f41c54257eec7d385c899b8da2e66e2044675cf /include/llvm
parentc7bd4827cd24ff63a604bbfb5f68f99da7498dce (diff)
rename addU64Imm() to addImm64()
git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@21223 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'include/llvm')
-rw-r--r--include/llvm/CodeGen/MachineInstrBuilder.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/llvm/CodeGen/MachineInstrBuilder.h b/include/llvm/CodeGen/MachineInstrBuilder.h
index ded06fc7d1f..060f90c53fd 100644
--- a/include/llvm/CodeGen/MachineInstrBuilder.h
+++ b/include/llvm/CodeGen/MachineInstrBuilder.h
@@ -108,9 +108,9 @@ public:
return *this;
}
/// addU64Imm - Add a new 64-bit immediate operand...
///
- const MachineInstrBuilder &addU64Imm(uint64_t Val) const {
+ const MachineInstrBuilder &addImm64(uint64_t Val) const {
MI->addZeroExtImm64Operand(Val);
return *this;
}
@@ -108,9 +108,9 @@ public:
return *this;
}
- /// addU64Imm - Add a new 64-bit immediate operand...
+ /// addImm64 - Add a new 64-bit immediate operand...
///